# coding: utf-8

"""
    Weheat Backend

    This is the backend for the Weheat project

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, StrictStr
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class EnergyViewDto(BaseModel):
    """
    EnergyViewDto
    """ # noqa: E501
    interval: Optional[StrictStr] = Field(default=None, description="Interval of this EnergyViewDto (Correct intervals include: \"Hour\", \"Day\", \"Week\", \"Month\", \"Year\")")
    time_bucket: Optional[datetime] = Field(default=None, alias="timeBucket")
    total_ein_heating: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going into the heat pump for heating for this interval (in kwh)", alias="totalEInHeating")
    total_ein_dhw: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going into the heat pump for doing DHW for this interval (in kwh)", alias="totalEInDhw")
    total_ein_heating_defrost: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going into the heat pump for defrosting whilst heating for this interval (in kwh)", alias="totalEInHeatingDefrost")
    total_ein_dhw_defrost: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going into the heat pump for defrosting whilst doing DHW for this interval (in kwh)", alias="totalEInDhwDefrost")
    total_ein_cooling: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going into the heat pump for cooling for this interval (in kwh)", alias="totalEInCooling")
    total_e_out_heating: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going out of the heat pump for heating for this interval (in kwh)", alias="totalEOutHeating")
    total_e_out_dhw: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going out of the heat pump for doing DHW for this interval (in kwh)", alias="totalEOutDhw")
    total_e_out_heating_defrost: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going out of the heat pump for defrosting whilst heating for this interval (in kwh)", alias="totalEOutHeatingDefrost")
    total_e_out_dhw_defrost: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going out of the heat pump for defrosting whilst doing DHW for this interval (in kwh)", alias="totalEOutDhwDefrost")
    total_e_out_cooling: Union[StrictFloat, StrictInt] = Field(description="Total energy from electricity going out of the heat pump for cooling for this interval (in kwh)", alias="totalEOutCooling")
    average_power_ein_heating: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going into the heat pump for heating for this interval (in kW)", alias="averagePowerEInHeating")
    average_power_ein_dhw: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going into the heat pump for doing DHW for this interval (in kW)", alias="averagePowerEInDhw")
    average_power_ein_heating_defrost: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going into the heat pump for defrosting whilst heating for this interval (in kW)", alias="averagePowerEInHeatingDefrost")
    average_power_ein_dhw_defrost: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going into the heat pump for defrosting whilst doing DHW for this interval (in kW)", alias="averagePowerEInDhwDefrost")
    average_power_ein_cooling: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going into the heat pump for cooling for this interval (in kW)", alias="averagePowerEInCooling")
    average_power_e_out_heating: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going out of the heat pump for heating for this interval (in kW)", alias="averagePowerEOutHeating")
    average_power_e_out_dhw: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going out of the heat pump for doing DHW for this interval (in kW)", alias="averagePowerEOutDhw")
    average_power_e_out_heating_defrost: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going out of the heat pump for defrosting whilst heating for this interval (in kW)", alias="averagePowerEOutHeatingDefrost")
    average_power_e_out_dhw_defrost: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going out of the heat pump for defrosting whilst doing DHW for this interval (in kW)", alias="averagePowerEOutDhwDefrost")
    average_power_e_out_cooling: Union[StrictFloat, StrictInt] = Field(description="Average power from electricity going out of the heat pump for cooling for this interval (in kW)", alias="averagePowerEOutCooling")
    __properties: ClassVar[List[str]] = ["interval", "timeBucket", "totalEInHeating", "totalEInDhw", "totalEInHeatingDefrost", "totalEInDhwDefrost", "totalEInCooling", "totalEOutHeating", "totalEOutDhw", "totalEOutHeatingDefrost", "totalEOutDhwDefrost", "totalEOutCooling", "averagePowerEInHeating", "averagePowerEInDhw", "averagePowerEInHeatingDefrost", "averagePowerEInDhwDefrost", "averagePowerEInCooling", "averagePowerEOutHeating", "averagePowerEOutDhw", "averagePowerEOutHeatingDefrost", "averagePowerEOutDhwDefrost", "averagePowerEOutCooling"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of EnergyViewDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if interval (nullable) is None
        # and model_fields_set contains the field
        if self.interval is None and "interval" in self.model_fields_set:
            _dict['interval'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of EnergyViewDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "interval": obj.get("interval"),
            "timeBucket": obj.get("timeBucket"),
            "totalEInHeating": obj.get("totalEInHeating"),
            "totalEInDhw": obj.get("totalEInDhw"),
            "totalEInHeatingDefrost": obj.get("totalEInHeatingDefrost"),
            "totalEInDhwDefrost": obj.get("totalEInDhwDefrost"),
            "totalEInCooling": obj.get("totalEInCooling"),
            "totalEOutHeating": obj.get("totalEOutHeating"),
            "totalEOutDhw": obj.get("totalEOutDhw"),
            "totalEOutHeatingDefrost": obj.get("totalEOutHeatingDefrost"),
            "totalEOutDhwDefrost": obj.get("totalEOutDhwDefrost"),
            "totalEOutCooling": obj.get("totalEOutCooling"),
            "averagePowerEInHeating": obj.get("averagePowerEInHeating"),
            "averagePowerEInDhw": obj.get("averagePowerEInDhw"),
            "averagePowerEInHeatingDefrost": obj.get("averagePowerEInHeatingDefrost"),
            "averagePowerEInDhwDefrost": obj.get("averagePowerEInDhwDefrost"),
            "averagePowerEInCooling": obj.get("averagePowerEInCooling"),
            "averagePowerEOutHeating": obj.get("averagePowerEOutHeating"),
            "averagePowerEOutDhw": obj.get("averagePowerEOutDhw"),
            "averagePowerEOutHeatingDefrost": obj.get("averagePowerEOutHeatingDefrost"),
            "averagePowerEOutDhwDefrost": obj.get("averagePowerEOutDhwDefrost"),
            "averagePowerEOutCooling": obj.get("averagePowerEOutCooling")
        })
        return _obj





# coding: utf-8

"""
    Weheat Backend

    This is the backend for the Weheat project

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
import re  # noqa: F401
from enum import Enum



try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class HeatPumpModel(int, Enum):
    """
    Model of the heat pump   - BlackBirdP80: BlackBird P80 heat pump (0)   - BlackBirdP60: BlackBird P60 heat pump (1)   - SparrowP60Brown: Sparrow P60 heat pump, colour brown (default) (2)   - SparrowP60Green: Sparrow P60 heat pump, colour green (3)   - SparrowP60Grey: Sparrow P60 heat pump, colour grey (4)   - FlintP40: Flint P40 heat pump (5)
    """

    """
    allowed enum values
    """
    NUMBER_0 = 0
    NUMBER_1 = 1
    NUMBER_2 = 2
    NUMBER_3 = 3
    NUMBER_4 = 4
    NUMBER_5 = 5

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of HeatPumpModel from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Weheat Backend

    This is the backend for the Weheat project

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501
import pathlib

from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "weheat"
VERSION = "2025.2.13"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "aiohttp >= 3.0.0",
    "aiohttp-retry >= 2.8.3",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Weheat Backend client",
    author="Jesper Raemaekers",
    author_email="jesper.raemaekers@wefabricate.com",
    url="https://github.com/wefabricate/wh-python",
    keywords=["OpenAPI", "OpenAPI-Generator", "Weheat Backend"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description=pathlib.Path("README.md").read_text(),  # noqa: E501
    package_data={"weheat": ["py.typed"]},
    license="MIT",
    license_files=('LICENSE',),
)



# flake8: noqa

# import apis into api package
from weheat.api.energy_log_api import EnergyLogApi
from weheat.api.heat_pump_api import HeatPumpApi
from weheat.api.heat_pump_log_api import HeatPumpLogApi
from weheat.api.user_api import UserApi




# coding: utf-8

# flake8: noqa

"""
    Weheat Backend

    This is the backend for the Weheat project

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2024.11.15"

# import apis into sdk package
from weheat.api.energy_log_api import EnergyLogApi
from weheat.api.heat_pump_api import HeatPumpApi
from weheat.api.heat_pump_log_api import HeatPumpLogApi
from weheat.api.user_api import UserApi

# import ApiClient
from weheat.api_response import ApiResponse
from weheat.api_client import ApiClient
from weheat.configuration import Configuration
from weheat.exceptions import OpenApiException
from weheat.exceptions import ApiTypeError
from weheat.exceptions import ApiValueError
from weheat.exceptions import ApiKeyError
from weheat.exceptions import ApiAttributeError
from weheat.exceptions import ApiException

# import models into sdk package
from weheat.models.boiler_type import BoilerType
from weheat.models.device_state import DeviceState
from weheat.models.dhw_type import DhwType
from weheat.models.energy_view_dto import EnergyViewDto
from weheat.models.heat_pump_log_view_dto import HeatPumpLogViewDto
from weheat.models.heat_pump_model import HeatPumpModel
from weheat.models.heat_pump_status_enum import HeatPumpStatusEnum
from weheat.models.heat_pump_type import HeatPumpType
from weheat.models.raw_heat_pump_log_dto import RawHeatPumpLogDto
from weheat.models.read_all_heat_pump_dto import ReadAllHeatPumpDto
from weheat.models.read_heat_pump_dto import ReadHeatPumpDto
from weheat.models.read_user_dto import ReadUserDto
from weheat.models.read_user_me_dto import ReadUserMeDto
from weheat.models.role import Role
